@@ -45,7 +45,7 @@ QCanBusDeviceInfo::~QCanBusDeviceInfo() = default;
 /*!
     \fn QCanBusDeviceInfo &QCanBusDeviceInfo::operator=(QCanBusDeviceInfo &&other)
 
-    Move-assigns other to this QCanBusDeviceInfo instance.
+    Move-assigns \a other to this QCanBusDeviceInfo instance.
 */
 
 /*!
@@ -108,7 +108,7 @@ QString QCanBusDeviceInfo::serialNumber() const
 
     \note In contrast to serialNumber(), the alias is not guaranteed to be unique.
 
-    If that function is not supported by the CAN plugin, an empty string is returned.
+    If this function is not supported by the CAN plugin, an empty string is returned.
     \sa serialNumber()
 */
 QString QCanBusDeviceInfo::alias() const
